@@ -32,6 +32,7 @@ from tqdm import tqdm
 
 from disent.dataset import DisentDataset
 from disent.metrics import utils
+from disent.metrics.utils import make_metric
 from disent.util import to_numpy
 
 
@@ -43,6 +44,7 @@ log = logging.getLogger(__name__)
 # ========================================================================= #
 
 
+@make_metric('factor_vae', fast_kwargs=dict(num_train=700,  num_eval=350, num_variance_estimate=1000))  # may not be accurate, but it just takes waay too long otherwise 20+ seconds
 def metric_factor_vae(
         dataset: DisentDataset,
         representation_function: callable,
@@ -124,8 +126,8 @@ def metric_factor_vae(
     eval_accuracy = np.sum(eval_votes[classifier, other_index]) * 1. / np.sum(eval_votes)
 
     return {
-        "factor_vae.train_accuracy": train_accuracy,
-        "factor_vae.eval_accuracy": eval_accuracy,
+        "factor_vae.train_accuracy": train_accuracy,    # "z-min variance" -- Measuring Disentanglement: A Review of Metrics
+        "factor_vae.eval_accuracy": eval_accuracy,      # "z-min variance" -- Measuring Disentanglement: A Review of Metrics
         "factor_vae.num_active_dims": len(active_dims),
     }
 
